@@ -24,6 +24,7 @@
 #endif
 
 #include <gtk/gtk.h>
+#include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
 #include <gio/gio.h>
 #include <mate-panel-applet.h>
@@ -415,8 +416,6 @@ cpufreq_applet_popup_position_menu (GtkMenu  *menu,
         GtkAllocation   allocation;
         gint            menu_xpos;
         gint            menu_ypos;
-        gint            sc_width;
-        gint            sc_height;
 
         widget = GTK_WIDGET (gdata);
 
@@ -426,23 +425,20 @@ cpufreq_applet_popup_position_menu (GtkMenu  *menu,
 
         gtk_widget_get_allocation (widget, &allocation);
 
-        gdk_window_get_geometry (gdk_screen_get_root_window (gtk_widget_get_screen (widget)), NULL, NULL,
-                                 &sc_width, &sc_height);
-
         menu_xpos += allocation.x;
         menu_ypos += allocation.y;
 
         switch (mate_panel_applet_get_orient (MATE_PANEL_APPLET (widget))) {
         case MATE_PANEL_APPLET_ORIENT_DOWN:
         case MATE_PANEL_APPLET_ORIENT_UP:
-                if (menu_ypos > sc_height / 2)
+                if (menu_ypos > HeightOfScreen (gdk_x11_screen_get_xscreen (gtk_widget_get_screen (widget))) / 2)
                         menu_ypos -= requisition.height;
                 else
                         menu_ypos += allocation.height;
                 break;
         case MATE_PANEL_APPLET_ORIENT_RIGHT:
         case MATE_PANEL_APPLET_ORIENT_LEFT:
-                if (menu_xpos > sc_width / 2)
+                if (menu_xpos > WidthOfScreen (gdk_x11_screen_get_xscreen (gtk_widget_get_screen (widget))) / 2)
                         menu_xpos -= requisition.width;
                 else
                         menu_xpos += allocation.width;
@@ -621,7 +617,7 @@ cpufreq_applet_about_cb (GtkAction     *action,
                          CPUFreqApplet *applet)
 {
         char copyright[] = \
-                "Copyright \xc2\xa9 2012-2016 MATE developers\n"
+                "Copyright \xc2\xa9 2012-2018 MATE developers\n"
                 "Copyright \xC2\xA9 2004 Carlos Garcia Campos";
 
         static const gchar *const authors[] = {
@@ -782,6 +778,7 @@ cpufreq_applet_update (CPUFreqApplet *applet, CPUFreqMonitor *monitor)
         gint         freq;
         gint         perc;
         guint        cpu;
+        GtkRequisition  req;
         const gchar *governor;
 
         cpu = cpufreq_monitor_get_cpu (monitor);
@@ -794,6 +791,9 @@ cpufreq_applet_update (CPUFreqApplet *applet, CPUFreqMonitor *monitor)
 
         if (applet->show_freq) {
                 gtk_label_set_text (GTK_LABEL (applet->label), freq_label);
+                /*Hold the largest size set by any jumping text */
+                gtk_widget_get_preferred_size (GTK_WIDGET (applet->label),&req, NULL);
+                gtk_widget_set_size_request (GTK_WIDGET (applet->label),req.width, req.height);
         }
 
         if (applet->show_perc) {
@@ -876,29 +876,34 @@ cpufreq_applet_get_widget_size (CPUFreqApplet *applet,
 static void
 cpufreq_applet_refresh (CPUFreqApplet *applet)
 {
-        gint      total_size = 0;
-        gint      panel_size, label_size;
-        gint      unit_label_size, pixmap_size;
-        gint      size_step = 12;
-	gboolean  horizontal;
-        gboolean  do_unref = FALSE;
+    gint      total_size = 0;
+    gint      panel_size, label_size;
+    gint      unit_label_size, pixmap_size;
+    gint      size_step = 12;
+    gboolean  horizontal;
+    gboolean  do_unref = FALSE;
+    GtkRequisition  req;
 
-        panel_size = applet->size - 1; /* 1 pixel margin */
+    panel_size = applet->size - 1; /* 1 pixel margin */
 
-	horizontal = (applet->orient == MATE_PANEL_APPLET_ORIENT_UP ||
-		      applet->orient == MATE_PANEL_APPLET_ORIENT_DOWN);
+    horizontal = (applet->orient == MATE_PANEL_APPLET_ORIENT_UP ||
+             applet->orient == MATE_PANEL_APPLET_ORIENT_DOWN);
 
-        /* We want a fixed label size, the biggest */
-	if (horizontal)
-		label_size = cpufreq_applet_get_widget_size (applet, applet->label);
-	else
-		label_size = cpufreq_applet_get_max_label_width (applet);
+        /* Zero out and reset the size of the label in case the theme is getting smaller */
+    gtk_widget_set_size_request (GTK_WIDGET (applet->label), 0, 0);
+    gtk_widget_get_preferred_size (GTK_WIDGET (applet->label),&req, NULL);
+    gtk_widget_set_size_request (GTK_WIDGET (applet->label),req.width, req.height);
+       /* We want a fixed label size, the biggest */
+    if (horizontal)
+        label_size = cpufreq_applet_get_widget_size (applet, applet->label);
+    else
+        label_size = cpufreq_applet_get_max_label_width (applet);
         total_size += label_size;
 
-	if (horizontal)
-		unit_label_size = cpufreq_applet_get_widget_size (applet, applet->unit_label);
-	else
-		unit_label_size = cpufreq_applet_get_max_unit_width (applet);
+    if (horizontal)
+        unit_label_size = cpufreq_applet_get_widget_size (applet, applet->unit_label);
+    else
+        unit_label_size = cpufreq_applet_get_max_unit_width (applet);
         total_size += unit_label_size;
 
         pixmap_size = cpufreq_applet_get_widget_size (applet, applet->icon);
@@ -908,7 +913,7 @@ cpufreq_applet_refresh (CPUFreqApplet *applet)
                 do_unref = TRUE;
                 g_object_ref (applet->icon);
                 gtk_container_remove (GTK_CONTAINER (applet->box), applet->icon);
-		if (applet->labels_box) {
+        if (applet->labels_box) {
                         g_object_ref (applet->label);
                         gtk_container_remove (GTK_CONTAINER (applet->labels_box), applet->label);
                         g_object_ref (applet->unit_label);
@@ -917,13 +922,13 @@ cpufreq_applet_refresh (CPUFreqApplet *applet)
                 gtk_widget_destroy (applet->box);
         }
 
-	if (horizontal) {
-		applet->labels_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
-		if ((label_size + pixmap_size) <= panel_size)
-			applet->box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
-		else
-			applet->box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
-	} else {
+    if (horizontal) {
+        applet->labels_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
+        if ((label_size + pixmap_size) <= panel_size)
+            applet->box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
+        else
+            applet->box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
+    } else {
                 if (total_size <= panel_size) {
                         applet->box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
                         applet->labels_box  = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
